'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.fromAtoms = exports.withTheme = exports.lookupValue = undefined;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _intersection = require('lodash/intersection');

var _intersection2 = _interopRequireDefault(_intersection);

var _first = require('lodash/first');

var _first2 = _interopRequireDefault(_first);

var _keys = require('lodash/keys');

var _keys2 = _interopRequireDefault(_keys);

var _get2 = require('lodash/get');

var _get3 = _interopRequireDefault(_get2);

var _styledComponents = require('styled-components');

var _theme = require('../theme');

var _theme2 = _interopRequireDefault(_theme);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// Return the value of a set of props against a lookup object.
// Helps when using "ternary" props, ie: <Text small bold />
// Third argument is the default value to return in the event of an `undefined`;
var lookupValue = exports.lookupValue = function lookupValue(props, lookup, _default) {
  var matches = (0, _intersection2.default)((0, _keys2.default)(props), (0, _keys2.default)(lookup));

  if (matches.length > 1) {
    throw new Error('You have specified conflicting props: ' + JSON.stringify(matches));
  }

  return lookup[(0, _first2.default)(matches)] || _default;
};

var withTheme = exports.withTheme = function withTheme(component) {
  return _react2.default.createElement(
    _styledComponents.ThemeProvider,
    { theme: _theme2.default },
    component
  );
};

// Shorthand for gettings values from the theme.
// `variationKey` is a string matching the prop to use to lookup `field`.
// See <Button /> or <Alert /> for an example.
var fromAtoms = exports.fromAtoms = function fromAtoms(component, variationKey, field) {
  return function (props) {
    return (0, _get3.default)(props.theme.atoms, [component, (0, _get3.default)(props, variationKey), field]);
  };
};